package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jun 14, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Mode struct {
Name string `json:"name"`
John *string `json:"john"`
Hashcat *int `json:"hashcat"`
Extended bool `json:"extended"`
}
type Prototypes struct {
Regex string `json:"regex"`
Modes []Mode `json:"modes"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.